% Generated by roxygen2 (4.0.1): do not edit by hand
\name{plotpseudotime}
\alias{plotpseudotime}
\title{plotpseudotime}
\usage{
plotpseudotime(pseudotimedata, x = 1, y = 2, show_tree = T,
  show_cell_names = T, cell_name_size = 3, markerexpr = NULL)
}
\arguments{
\item{pseudotimedata}{The exact output from \code{\link{TSPpseudotime}}.}

\item{x}{The column of data after dimension reduction to be plotted on the horizontal axis.}

\item{y}{The column of data after dimension reduction to be plotted on the vertical axis.}

\item{show_tree}{Whether to show the links between cells connected in the minimum spanning tree.}

\item{show_cell_names}{Whether to draw the name of each cell in the plot.}

\item{cell_name_size}{The size of cell name labels if show_cell_names is TRUE.}

\item{markerexpr}{The gene expression used to define the size of nodes.}
}
\value{
A ggplot2 object.
}
\description{
Plot the TSP constructed pseudotime time
}
\details{
This function will plot the gene expression data after dimension reduction and link the data points with the constructed pseudotime path. It is written by plot_spanning_tree functioin in package monocle.
}
\examples{
data(lpsdata)
procdata <- preprocess(lpsdata)
#Choose STAT2 gene expression as marker gene
STAT2expr <- log2(lpsdata["STAT2",]+1)
lpspseudotime <- TSPpseudotime(procdata, geneexpr = STAT2expr, dim = 2)
plotpseudotime(lpspseudotime, markerexpr = STAT2expr)
}
\author{
Zhicheng Ji, Hongkai Ji <zji4@zji4.edu>
}
\references{
Cole Trapnell and Davide Cacchiarelli et al (2014): The dynamics and regulators of cell fate decisions are revealed by pseudo-temporal ordering of single cells. Nature Biotechnology
}
\seealso{
\code{\link{TSPpseudotime}} for examples
}

